pub(super) enum Backing {
Contiguous(Frames<false>),
Discontiguous {
pmm: DynPmm<'static, false>,
frame_count: usize,
},
Vmo {
handle: Arc<Handle>,
frame_count: usize,
},
}Available on crate feature
full only.Expand description
Used to track if the memory underlying the mapping is contiguous
Variants
Contiguous(Frames<false>)
The underlying physical memory is contiguous, and starts at the contained frame
Discontiguous
The underlying physical memory is discontiguous, but all allocated by the same
Vmo
The mapping is backed by a VMO handle